@@ -96,7 +96,7 @@ orm.Query.paginate = paginate
 import time
 import logging, sys
 import threading
-from bffacilities import createLogger
+from bffacilities.utils import createLogger
 
 class Database(object):
     """Recommond Usage: 
