@@ -441,6 +441,7 @@ class HeatmapLoss(nn.Module):
             #     # hmloss = self._forward(preds, hms)
             #     loss_dict[f"hmloss_{i}"] = hmloss.mean()
         return loss_dict
+        
 class CrossEntropyHeatmapLoss(HeatmapLoss):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -454,7 +455,8 @@ class CrossEntropyHeatmapLoss(HeatmapLoss):
         # l = l.mean(dim=3).mean(dim=2).mean(dim=1)
         l = l.mean(dim=3).mean(dim=2).mean(dim=1)           
         return l ## l of dim bsize
-    def forward(self, ):
+
+    def forward(self, hm_preds):
         S = len(hm_preds)
         N, K, H, W = hm_preds[0].shape
         device = hm_preds[0].device
